﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;

namespace Resizer
{
    class ResizeController
    {
        ImageFolders _imageFolders;
        IImageIO _imageIo;
        ImageResizer _resizer;
        ScaleCalculator _scaleCalculator;

        // production constructor
        public ResizeController(string sourceFolder, string destFolder, int size)
            :
            this(new ImageFolders(sourceFolder, destFolder), new ImageIO(), new ImageResizer(), new ScaleCalculator(size))
        {
        }

        // test constructor
        public ResizeController(ImageFolders imageFolders, IImageIO imageIo, ImageResizer resizer, ScaleCalculator scaleCalculator)
        {
            _imageFolders = imageFolders;
            _imageIo = imageIo;
            _resizer = resizer;
            _scaleCalculator = scaleCalculator;
        }

        public void DoResize()
        {
            foreach (string file in _imageFolders.GetSourceFiles())
            {
                using (Image image = _imageIo.ReadImage(file))
                {
                    Size size = _scaleCalculator.Resize(image.Size);
                    using (Image result = _resizer.Resize(image, size))
                    {
                        string destFile = _imageFolders.GetDestFileName(file);
                        _imageIo.SaveImage(result, destFile);
                    }
                }
            }
        }
    }
}
